==> dotnet8_8.0.100-8.0.0~rc1.orig.tar.xz: src/roslyn/src/Features/RulesMissingDocumentation.md <==
# Rules without documentation

Rule ID | Missing Help Link | Title |
--------|-------------------|-------|
IDE0005_gen |  | Imports statement is unnecessary. |
IDE0043 |  | Invalid format string |
IDE0240 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0240> | Remove redundant nullable directive |
IDE0241 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0241> | Remove unnecessary nullable directive |
IDE0250 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0250> | Make struct 'readonly' |
IDE0251 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0251> | Make member 'readonly' |
IDE0260 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0260> | Use pattern matching |
IDE0270 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0270> | Use coalesce expression |
IDE0280 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0280> | Use 'nameof' |
IDE0290 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0290> | Use primary constructor |
IDE0300 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0300> | Simplify collection initialization |
IDE0301 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0301> | Simplify collection initialization |
IDE0302 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0302> | Simplify collection initialization |
IDE0303 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0303> | Simplify collection initialization |
IDE0304 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0304> | Simplify collection initialization |
IDE1007 |  |  |
IDE2000 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2000> | Avoid multiple blank lines |
IDE2001 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2001> | Embedded statements must be on their own line |
IDE2002 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2002> | Consecutive braces must not have blank line between them |
IDE2003 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2003> | Blank line required between block and subsequent statement |
IDE2004 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2004> | Blank line not allowed after constructor initializer colon |
IDE2005 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2005> | Blank line not allowed after conditional expression token |
IDE2006 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2006> | Blank line not allowed after arrow expression clause token |
JSON001 |  | Invalid JSON pattern |
JSON002 |  | Probable JSON string detected |
RE0001 |  | Invalid regex pattern |
RemoveUnnecessaryImportsFixable |  |  |

==> dotnet8_8.0.124-8.0.24.orig.tar.xz: src/roslyn/src/Features/RulesMissingDocumentation.md <==
# Rules without documentation

Rule ID | Missing Help Link | Title |
--------|-------------------|-------|
IDE0005_gen |  | Imports statement is unnecessary. |
IDE0043 |  | Invalid format string |
IDE0240 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0240> | Remove redundant nullable directive |
IDE0241 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0241> | Remove unnecessary nullable directive |
IDE0250 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0250> | Make struct 'readonly' |
IDE0251 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0251> | Make member 'readonly' |
IDE0260 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0260> | Use pattern matching |
IDE0270 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0270> | Use coalesce expression |
IDE0280 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0280> | Use 'nameof' |
IDE0290 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0290> | Use primary constructor |
IDE0300 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0300> | Simplify collection initialization |
IDE0301 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0301> | Simplify collection initialization |
IDE0302 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0302> | Simplify collection initialization |
IDE0303 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0303> | Simplify collection initialization |
IDE0304 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0304> | Simplify collection initialization |
IDE0305 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0305> | Simplify collection initialization |
IDE1007 |  |  |
IDE2000 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2000> | Avoid multiple blank lines |
IDE2001 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2001> | Embedded statements must be on their own line |
IDE2002 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2002> | Consecutive braces must not have blank line between them |
IDE2003 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2003> | Blank line required between block and subsequent statement |
IDE2004 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2004> | Blank line not allowed after constructor initializer colon |
IDE2005 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2005> | Blank line not allowed after conditional expression token |
IDE2006 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2006> | Blank line not allowed after arrow expression clause token |
JSON001 |  | Invalid JSON pattern |
JSON002 |  | Probable JSON string detected |
RE0001 |  | Invalid regex pattern |
RemoveUnnecessaryImportsFixable |  |  |
